@@ -228,7 +228,9 @@ class Character:
 
     def keys(self):
         keys = [key for key in self.__dict__ if not key.startswith("_")]
-        keys.append("experience")
+        keys.extend(
+            ["experience", "death_saves", "death_fails", "dexterity", "dead", "hp"]
+        )
         return keys
 
     def values(self):
@@ -237,7 +239,16 @@ class Character:
             for key, value in self.__dict__.items()
             if not key.startswith("_")
         ]
-        vals.append(self._experience._experience)
+        vals.extend(
+            [
+                self._experience._experience,
+                self._death_saves,
+                self._death_fails,
+                self._dexterity,
+                self._dead,
+                self._hp,
+            ]
+        )
         return vals
 
     def __getitem__(self, key):
@@ -302,7 +313,8 @@ class Character:
     @dexterity.setter
     def dexterity(self, new_value):
         self._dexterity = new_value
-        self.armour_class = 10 + Character.getModifier(new_value)
+        for item in self.inventory:
+            self.applyArmourClass(item)
 
     @property
     def experience(self):
@@ -425,23 +437,27 @@ class Character:
             ):
                 self.inventory.pop(i)
 
-    def giveItem(self, item: dict):
-        """
-        Adds an item to the Character's inventory list, as a dictionary.
-        If the item is armour or a shield, the armour_class attribute will be set
-        and any other armour/shields in the inventory will be removed.
-        """
+    def applyArmourClass(self, item: dict):
         if item["equipment_category"]["index"] == "armor":
             if item["armor_category"] == "Shield":
                 self.removeShields()
                 self.armour_class += item["armor_class"]["base"]
             else:
                 self.removeArmour()
-                self.armour_class = (
-                    item["armor_class"]["base"] + Character.getModifier(self.dexterity)
-                    if item["armor_class"]["dex_bonus"]
-                    else 0
+                self.armour_class = item["armor_class"]["base"] + (
+                    0
+                    if not item["armor_class"]["dex_bonus"]
+                    else Character.getModifier(self.dexterity)
                 )
+
+    def giveItem(self, item: dict):
+        """
+        Adds an item to the Character's inventory list, as a dictionary.
+        If the item is armour or a shield, the armour_class attribute will be set
+        and any other armour/shields in the inventory will be removed.
+        """
+        self.applyArmourClass(item)
+
         self.inventory.append(item)
 
     def removeItem(self, item):
